Draws a curve corresponding to a function over the interval [from, to] in an interactive plot using 'Chart.js'.
Usage
# S3 method for class '`function`'
plotjs(x, from = 0, to = 1, ylab = NULL, ...)Draws a curve corresponding to a function over the interval [from, to] in an interactive plot using 'Chart.js'.
# S3 method for class '`function`'
plotjs(x, from = 0, to = 1, ylab = NULL, ...)